package ru.ulstu.extractor.rule.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;
import ru.ulstu.extractor.rule.model.AddRuleForm;
import ru.ulstu.extractor.rule.service.AntecedentValueService;
import ru.ulstu.extractor.rule.service.RuleService;
import ru.ulstu.extractor.ts.service.TimeSeriesService;
import springfox.documentation.annotations.ApiIgnore;

import static ru.ulstu.extractor.core.Route.ADD_RULE;
import static ru.ulstu.extractor.core.Route.LIST_RULE;

@Controller
@ApiIgnore
public class RuleController {
    private final RuleService ruleService;
    private final AntecedentValueService antecedentValueService;
    private final TimeSeriesService timeSeriesService;

    public RuleController(RuleService ruleService, AntecedentValueService antecedentValueService, TimeSeriesService timeSeriesService) {
        this.ruleService = ruleService;
        this.antecedentValueService = antecedentValueService;
        this.timeSeriesService = timeSeriesService;
    }

    @GetMapping(LIST_RULE)
    public String getList(Model model) {
        model.addAttribute("rules", ruleService.getList());
        return LIST_RULE;
    }

    @GetMapping(ADD_RULE)
    public String getAntecedent(Model model) {
        model.addAttribute("antecedentValues", antecedentValueService.getList());
        model.addAttribute("antecedents", timeSeriesService.getAllTimeSeries());
        model.addAttribute("addRuleForm", new AddRuleForm());
        return ADD_RULE;
    }

    @RequestMapping(value = ADD_RULE, method = RequestMethod.POST)
    public String addRule(@ModelAttribute AddRuleForm ruleForm, Model model, RedirectAttributes redirectAttributes) {
        ruleService.saveRule(ruleForm);
        return "redirect:/" + LIST_RULE;
    }
}
