package ru.ulstu.extractor.ts.creator;

import org.springframework.stereotype.Component;
import ru.ulstu.extractor.commit.service.CommitService;
import ru.ulstu.extractor.gitrepository.service.GitRepositoryService;
import ru.ulstu.extractor.ts.model.TimeSeriesValue;
import ru.ulstu.extractor.ts.service.TimeSeriesService;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Component
public class CommitsTS extends AbstractTimeSeriesCreator {
    private final TimeSeriesService timeSeriesService;
    private final CommitService commitService;
    private final GitRepositoryService gitRepositoryService;

    public CommitsTS(TimeSeriesService timeSeriesService,
                     CommitService commitService,
                     GitRepositoryService gitRepositoryService) {
        this.timeSeriesService = timeSeriesService;
        this.commitService = commitService;
        this.gitRepositoryService = gitRepositoryService;
    }

    @Override
    public String getTimeSeriesName() {
        return "Количество коммитов во времени";
    }

    @Override
    public Map<String, List<TimeSeriesValue>> getTimeSeriesValues(Integer repositoryId, String branchName) {
        //TODO: добавить постраничное чтение
        Map<String, List<TimeSeriesValue>> result = new HashMap<>();
        result.put(String.format("%s %s %s", gitRepositoryService.findById(repositoryId).getName(),
                        branchName,
                        getTimeSeriesName()),
                commitService.findByRepositoryIdAndName(repositoryId, branchName)
                        .stream()
                        .map(c -> new TimeSeriesValue(c.getDate(), 1.0))
                        .collect(Collectors.toList()));
        return result;
    }

    @Override
    public TimeSeriesService getTimeSeriesService() {
        return timeSeriesService;
    }
}
